AWS ParallelCluster Node
========================

[![PyPI Version](https://img.shields.io/pypi/v/aws-parallelcluster-node)](https://pypi.org/project/aws-parallelcluster-node/)
[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![codecov](https://codecov.io/gh/aws/aws-parallelcluster-node/branch/develop/graph/badge.svg)](https://codecov.io/gh/aws/aws-parallelcluster-node)
[![ParallelCluster CI](https://github.com/aws/aws-parallelcluster-node/workflows/ParallelCluster%20CI/badge.svg)](https://github.com/aws/aws-parallelcluster-node/actions)

This repo contains the aws-parallelcluster-node package installed on the Amazon EC2 instances launched
as part of AWS ParallelCluster.